@@ -5,7 +5,7 @@ use strict;
 use warnings;
 use Carp qw/croak/;
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 require XSLoader;
 XSLoader::load('Class::XSAccessor::Array', $VERSION);
@@ -17,35 +17,36 @@ sub import {
   my %opts = @_;
 
   my $replace = $opts{replace} || 0;
+  my $chained = $opts{chained} || 0;
 
   my $read_subs = $opts{getters} || {};
-  my $set_subs = $opts{setters} || {};
-  my $acc_subs = $opts{accessors} || {};
+  my $set_subs  = $opts{setters} || {};
+  my $acc_subs  = $opts{accessors} || {};
   my $pred_subs = $opts{predicates} || {};
 
   foreach my $subname (keys %$read_subs) {
     my $arrayIndex = $read_subs->{$subname};
-    _generate_accessor($caller_pkg, $subname, $arrayIndex, $replace, "getter");
+    _generate_accessor($caller_pkg, $subname, $arrayIndex, $replace, $chained, "getter");
   }
 
   foreach my $subname (keys %$set_subs) {
     my $arrayIndex = $set_subs->{$subname};
-    _generate_accessor($caller_pkg, $subname, $arrayIndex, $replace, "setter");
+    _generate_accessor($caller_pkg, $subname, $arrayIndex, $replace, $chained, "setter");
   }
 
   foreach my $subname (keys %$acc_subs) {
     my $arrayIndex = $acc_subs->{$subname};
-    _generate_accessor($caller_pkg, $subname, $arrayIndex, $replace, "accessor");
+    _generate_accessor($caller_pkg, $subname, $arrayIndex, $replace, $chained, "accessor");
   }
 
   foreach my $subname (keys %$pred_subs) {
     my $arrayIndex = $pred_subs->{$subname};
-    _generate_accessor($caller_pkg, $subname, $arrayIndex, $replace, "predicate");
+    _generate_accessor($caller_pkg, $subname, $arrayIndex, $replace, $chained, "predicate");
   }
 }
 
 sub _generate_accessor {
-  my ($caller_pkg, $subname, $arrayIndex, $replace, $type) = @_;
+  my ($caller_pkg, $subname, $arrayIndex, $replace, $chained, $type) = @_;
 
   if (not defined $arrayIndex) {
     croak("Cannot use undef as a array index for generating an XS $type accessor. (Sub: $subname)");
@@ -77,13 +78,13 @@ sub _generate_accessor {
     newxs_getter($subname, $arrayIndex);
   }
   elsif ($type eq 'setter') {
-    newxs_setter($subname, $arrayIndex);
+    newxs_setter($subname, $arrayIndex, $chained);
   }
   elsif ($type eq 'predicate') {
     newxs_predicate($subname, $arrayIndex);
   }
   else {
-    newxs_accessor($subname, $arrayIndex);
+    newxs_accessor($subname, $arrayIndex, $chained);
   }
 }
 
@@ -141,6 +142,36 @@ The method names may be fully qualified. In the example of the
 synopsis, you could have written C<MyClass::get_foo> instead
 of C<get_foo>.
 
+=head1 OPTIONS
+
+In addition to specifying the types and names of accessors, you can add options
+which modify behaviour. The options are specified as key/value pairs just as the
+accessor declaration. Example:
+
+  use Class::XSAccessor::Array
+    getters => {
+      get_foo => 0,
+    },
+    replace => 1;
+
+The list of available options is:
+
+=head2 replace
+
+Set this to a true value to prevent C<Class::XSAccessor::Array> from
+complaining about replacing existing subroutines.
+
+=head2 chained
+
+Set this to a true value to change the return value of setters
+and mutators (when called with an argument).
+If C<chained> is enabled, the setters and accessors/mutators will
+return the object. Mutators called without an argument still
+return the value of the associated attribute.
+
+As with the other options, C<chained> affects all methods generated
+in the same C<use Class::XSAccessor::Array ...> statement.
+
 =head1 CAVEATS
 
 Probably wouldn't work if your objects are I<tied>. But that's a strange thing to do anyway.
